pub struct AudioEncoding {
pub tokens: Vec<u32>,
pub audio: Audio,
}Expand description
Result of audio tokenization containing tokens and processed audio.
This struct encapsulates the output of audio encoding, containing both the token sequence and the processed audio data.
Fields
tokens- Token sequence (u32) representing the audio (includesbegin_audioand audio tokens)audio- Processed audio data after resampling and padding
Fields
tokens: Vec<u32>audio: AudioTrait Implementations
Sourceimpl Clone for AudioEncoding
impl Clone for AudioEncoding
Sourcefn clone(&self) -> AudioEncoding
fn clone(&self) -> AudioEncoding
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for AudioEncoding
impl RefUnwindSafe for AudioEncoding
impl Send for AudioEncoding
impl Sync for AudioEncoding
impl Unpin for AudioEncoding
impl UnwindSafe for AudioEncoding